@@ -1,7 +1,6 @@
 import json
 from pathlib import Path
 import sys
-from glob import glob
 from http import HTTPStatus
 import pkg_resources  # type: ignore
 
@@ -17,24 +16,18 @@ from fps_auth.backends import current_user  # type: ignore
 from fps_auth.models import User  # type: ignore
 
 from .config import get_lab_config  # type: ignore
+from .utils import get_federated_extensions
 
 
 def init_router(router, redirect_after_root):
     prefix_dir: Path = Path(sys.prefix)
     LOCALE = "en"
 
-    federated_extensions = []
+    extensions_dir = prefix_dir / "share" / "jupyter" / "labextensions"
+    federated_extensions, _ = get_federated_extensions(extensions_dir)
 
-    for path in glob(
-        str(prefix_dir / "share" / "jupyter" / "labextensions" / "**" / "package.json"),
-        recursive=True,
-    ):
-        with open(path) as f:
-            package = json.load(f)
-        name = package["name"]
-        extension = package["jupyterlab"]["_build"]
-        extension["name"] = name
-        federated_extensions.append(extension)
+    for ext in federated_extensions:
+        name = ext["name"]
         router.mount(
             f"/lab/extensions/{name}/static",
             StaticFiles(
@@ -136,7 +129,7 @@ def init_router(router, redirect_after_root):
             prefix_dir / "share" / "jupyter" / "lab" / "static" / "package.json"
         ) as f:
             package = json.load(f)
-        if name0 == "@jupyterlab":
+        if name0 in ["@jupyterlab", "@retrolab"]:
             lab_or_extensions = Path("lab")
         else:
             lab_or_extensions = Path("labextensions") / name0 / name1
